'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.injectExtractionFunctions = injectExtractionFunctions;

var _struct = require('./struct');

var FN_PREFIX = '___SV_INJECT';
var FN_PREFIX_IMPLICIT_GLOBAL = 'IG';
var FN_PREFIX_EXPLICIT_GLOBAL = 'EG';
var FN_SUFFIX_VALUE = 'VALUE';

/**
 * Create injection function and source for a file, category, declaration and result handler
 */
function createInjection(fileId, categoryPrefix, declaration, declarationResultHandler) {
  var fnName = FN_PREFIX + '_' + fileId + '_' + categoryPrefix + '_' + declaration.declarationClean;

  var injectedFunction = function injectedFunction(sassValue) {
    var value = (0, _struct.createStructuredValue)(sassValue);
    declarationResultHandler(declaration, value, sassValue);
    return sassValue;
  };

  var injectedCode = '$' + fnName + ': ' + fnName + '(' + declaration.declaration + ');\n';

  return { fnName: fnName, injectedFunction: injectedFunction, injectedCode: injectedCode };
}

/**
 * Create injection functions for extraction variable values
 * Returns injection sass source and the injected functions
 * Declaration result handlers will be called with the extracted value of each declaration
 * Provided file id will be used to ensure unique function names per file
 */
function injectExtractionFunctions(fileId, declarations, _ref) {
  var globalDeclarationResultHandler = _ref.globalDeclarationResultHandler;

  var injectedData = '';
  var injectedFunctions = {};

  // Create injections for implicit global variables
  declarations.implicitGlobals.forEach(function (declaration) {
    var _createInjection = createInjection(fileId, FN_PREFIX_IMPLICIT_GLOBAL, declaration, globalDeclarationResultHandler),
        fnName = _createInjection.fnName,
        injectedFunction = _createInjection.injectedFunction,
        injectedCode = _createInjection.injectedCode;

    injectedFunctions[fnName] = injectedFunction;
    injectedData += injectedCode;
  });

  // Create injections for explicit global variables
  declarations.explicitGlobals.forEach(function (declaration) {
    var _createInjection2 = createInjection(fileId, FN_PREFIX_EXPLICIT_GLOBAL, declaration, globalDeclarationResultHandler),
        fnName = _createInjection2.fnName,
        injectedFunction = _createInjection2.injectedFunction,
        injectedCode = _createInjection2.injectedCode;

    injectedFunctions[fnName] = injectedFunction;
    injectedData += injectedCode;
  });

  return { injectedData: injectedData, injectedFunctions: injectedFunctions };
}