'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseDeclarations = parseDeclarations;

var _nodeSass = require('node-sass');

var _nodeSass2 = _interopRequireDefault(_nodeSass);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REGEX_VARIABLE_GLOBAL_IMPLICIT = /(\$[\w-_]+)\s*:\s*((.*?[\r\n]?)+?);/g;
var REGEX_VARIABLE_GLOBAL_EXPLICIT = /(\$[\w-_]+)\s*:\s*(.*?)\s+!global\s*;/g;
var REGEX_DEEP_CONTEXT = /({[^{}]*})/g;
var REGEX_COMMENTS = /(\/\*(.*?[\r\n]?)+\*\/)|(\/\/.*?($|[\r\n]))/g;

/**
 * Strip a string for all occurences that matches provided regex
 */
function stripByRegex(data, regex) {
  var strippedData = data;

  var match = void 0;
  while (match = strippedData.match(regex)) {
    strippedData = strippedData.replace(match[0], '');
  }

  return strippedData;
}

/**
 * Extract variable declaration and expression from a chunk of sass source using provided regex
 */
function extractVariables(data, regex) {
  var variables = [];

  var matches = void 0;
  while (matches = regex.exec(data)) {
    var declaration = matches[1];
    var expression = matches[2];
    var declarationClean = declaration.replace('$', '');

    variables.push({ declaration: declaration, expression: expression, declarationClean: declarationClean });
  }

  return variables;
}

/**
 * Parse variables declarations from a chunk of sass source
 */
function parseDeclarations(data) {
  var decommentedData = stripByRegex(data, REGEX_COMMENTS);
  var decontextifiedData = stripByRegex(decommentedData, REGEX_DEEP_CONTEXT);

  var explicitGlobals = extractVariables(decommentedData, REGEX_VARIABLE_GLOBAL_EXPLICIT);
  var implicitGlobals = extractVariables(decontextifiedData, REGEX_VARIABLE_GLOBAL_IMPLICIT);

  return { explicitGlobals: explicitGlobals, implicitGlobals: implicitGlobals };
}