'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processFiles = processFiles;

var _inject = require('./inject');

var _parse = require('./parse');

/**
 * Get a string id for a filename
 */
function getFileId(filename) {
  return new Buffer(filename).toString('base64').replace(/=/g, '');
}

/**
 * Process a single sass files to get declarations, injected source and functions
 */
function processFile(filename, data) {
  var declarations = (0, _parse.parseDeclarations)(data);
  var variables = { global: {} };

  var globalDeclarationResultHandler = function globalDeclarationResultHandler(declaration, value) {
    variables.global[declaration.declaration] = { value: value, expression: declaration.expression };
  };

  var fileId = getFileId(filename);
  var injection = (0, _inject.injectExtractionFunctions)(fileId, declarations, { globalDeclarationResultHandler: globalDeclarationResultHandler });
  var injectedData = data + '\n\n' + injection.injectedData;
  var injectedFunctions = injection.injectedFunctions;

  return {
    fileId: fileId,
    declarations: declarations,
    variables: variables,
    injectedData: injectedData,
    injectedFunctions: injectedFunctions
  };
}

/**
 * Process a set of sass files to get declarations, injected source and functions
 * Files are provided in a map of filename -> key entries
 */
function processFiles(files) {
  var extractions = {};

  Object.keys(files).map(function (filename) {
    extractions[filename] = processFile(filename, files[filename]);
  });

  return extractions;
}