'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.serialize = serialize;

var _nodeSass = require('node-sass');

var _nodeSass2 = _interopRequireDefault(_nodeSass);

var _util = require('./util');

var _parseColor = require('parse-color');

var _parseColor2 = _interopRequireDefault(_parseColor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function serializeColor(sassColor) {
  if (sassColor.getA() !== 1) {
    return 'rgba(' + sassColor.getR() + ',' + sassColor.getG() + ',' + sassColor.getB() + ',' + sassColor.getA() + ')';
  } else {
    var hex = '#' + (0, _util.toColorHex)(sassValue.getR()) + (0, _util.toColorHex)(sassValue.getG()) + (0, _util.toColorHex)(sassValue.getB());
    var parsedColor = (0, _parseColor2.default)(hex);
    if (parsedColor.keyword != null) {
      return parsedColor.keyword;
    } else {
      return hex;
    }
  }
}

/**
 * Transform a SassValue into a serialized string
 */
function serializeValue(sassValue) {
  console.log('serializing', sassValue);

  var _ret = function () {
    switch (sassValue.constructor) {
      case _nodeSass2.default.types.String:
      case _nodeSass2.default.types.Boolean:
        return {
          v: '' + sassValue.getValue()
        };

      case _nodeSass2.default.types.Number:
        return {
          v: '' + sassValue.getValue() + sassValue.getUnit()
        };

      case _nodeSass2.default.types.Color:
        return {
          v: serializeColor(sassValue)
        };

      case _nodeSass2.default.types.Null:
        return {
          v: 'null'
        };

      case _nodeSass2.default.types.List:
        var listLength = sassValue.getLength();
        var listElement = [];
        for (var i = 0; i < listLength; i++) {
          listElement.push(serialize(sassValue.getValue(i)));
        }
        return {
          v: '[' + listElement.join(',') + ']'
        };

      case _nodeSass2.default.types.Map:
        var mapLength = sassValue.getLength();
        var mapValue = {};
        for (var _i = 0; _i < mapLength; _i++) {
          var key = serialize(sassValue.getKey(_i));
          var value = serialize(sassValue.getValue(_i));
          mapValue[key] = value;
        }
        var serializedMapValues = Object.keys(mapValue).map(function (key) {
          return key + ':' + mapValue[key];
        });
        return {
          v: '{' + serializedMapValues + '}'
        };

      default:
        throw new Error('Unsupported sass variable type \'' + sassValue.constructor.name + '\'');
    }
  }();

  if ((typeof _ret === 'undefined' ? 'undefined' : _typeof(_ret)) === "object") return _ret.v;
  ;
};

/**
 * Create a serialized string from a sassValue object
 */
function serialize(sassValue) {
  return serializeValue(sassValue);
};