'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createStructuredValue = createStructuredValue;

var _nodeSass = require('node-sass');

var _nodeSass2 = _interopRequireDefault(_nodeSass);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Convert a color value 0-255 to hex 00-FF
 */
function toColorHex(value) {
  var colorHex = value.toString(16);

  if (colorHex.length < 2) {
    colorHex = '0' + colorHex;
  }

  return colorHex;
}

/**
 * Transform a sassValue into a structured value based on the value type
 */
function makeValue(sassValue) {
  switch (sassValue.constructor) {
    case _nodeSass2.default.types.String:
    case _nodeSass2.default.types.Boolean:
      return { value: sassValue.getValue() };

    case _nodeSass2.default.types.Number:
      return { value: sassValue.getValue(), unit: sassValue.getUnit() };

    case _nodeSass2.default.types.Color:
      return {
        value: {
          r: sassValue.getR(),
          g: sassValue.getG(),
          b: sassValue.getB(),
          a: sassValue.getA(),
          hex: '#' + toColorHex(sassValue.getR()) + toColorHex(sassValue.getG()) + toColorHex(sassValue.getB())
        }
      };

    case _nodeSass2.default.types.Null:
      return { value: null };

    case _nodeSass2.default.types.List:
      var listLength = sassValue.getLength();
      var listValue = [];
      for (var i = 0; i < listLength; i++) {
        listValue.push(exports.createStructuredValue(sassValue.getValue(i)));
      }
      return { value: listValue };

    case _nodeSass2.default.types.Map:
      var mapLength = sassValue.getLength();
      var mapValue = {};
      for (var _i = 0; _i < mapLength; _i++) {
        mapValue[sassValue.getKey(_i).getValue()] = exports.createStructuredValue(sassValue.getValue(_i));
      }
      return { value: mapValue };

    default:
      throw new Error('Unsupported sass variable type \'' + sassValue.constructor.name + '\'');
  };
};

/**
 * Create a structured value definition from a sassValue object
 */
function createStructuredValue(sassValue) {
  var value = Object.assign({
    type: sassValue.constructor.name
  }, makeValue(sassValue));

  return value;
};